diff --git a/wp-admin/options-discussion.php b/wp-admin/options-discussion.php
index 0627f4d2ea..5f57819d4f 100644
--- a/wp-admin/options-discussion.php
+++ b/wp-admin/options-discussion.php
@@ -157,7 +157,7 @@ printf( __('Comments should be displayed with the %s comments at the top of each
' ); ?>
-moderation queue. One word or IP per line. It will match inside words, so “press” will match “WordPress”.'); ?>
+moderation queue. One word or IP address per line. It will match inside words, so “press” will match “WordPress”.'); ?>
@@ -166,7 +166,7 @@ printf( __('Comments should be displayed with the %s comments at the top of each
-
+
diff --git a/wp-includes/comment.php b/wp-includes/comment.php
index 0053ef5701..c015fea4f2 100644
--- a/wp-includes/comment.php
+++ b/wp-includes/comment.php
@@ -790,8 +790,8 @@ function check_comment_flood_db() {
* @global wpdb $wpdb WordPress database abstraction object.
*
* @param bool $is_flood Is a comment flooding occurring?
- * @param string $ip Comment IP.
- * @param string $email Comment author email address.
+ * @param string $ip Comment author's IP address.
+ * @param string $email Comment author's email address.
* @param string $date MySQL time string.
* @param bool $avoid_die When true, a disallowed comment will result in the function
* returning a WP_Error object, rather than executing wp_die().
@@ -1156,7 +1156,7 @@ function wp_check_comment_data_max_lengths( $comment_data ) {
* @param string $email The email of the comment
* @param string $url The url used in the comment
* @param string $comment The comment content
- * @param string $user_ip The comment author IP address
+ * @param string $user_ip The comment author's IP address
* @param string $user_agent The author's browser user agent
* @return bool True if comment contains blacklisted content, false if comment does not
*/
@@ -1834,11 +1834,11 @@ function wp_filter_comment($commentdata) {
*/
$commentdata['comment_content'] = apply_filters( 'pre_comment_content', $commentdata['comment_content'] );
/**
- * Filters the comment author's IP before it is set.
+ * Filters the comment author's IP address before it is set.
*
* @since 1.5.0
*
- * @param string $comment_author_ip The comment author's IP.
+ * @param string $comment_author_ip The comment author's IP address.
*/
$commentdata['comment_author_IP'] = apply_filters( 'pre_comment_user_ip', $commentdata['comment_author_IP'] );
/** This filter is documented in wp-includes/comment.php */
diff --git a/wp-includes/version.php b/wp-includes/version.php
index 305fe7d4d7..f075ffff92 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -4,7 +4,7 @@
*
* @global string $wp_version
*/
-$wp_version = '4.9-alpha-41703';
+$wp_version = '4.9-alpha-41704';
/**
* Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-includes/pluggable.php b/wp-includes/pluggable.php
index 41c144b9ab..32fab32f65 100644
--- a/wp-includes/pluggable.php
+++ b/wp-includes/pluggable.php
@@ -1469,8 +1469,8 @@ function wp_notify_postauthor( $comment_id, $deprecated = null ) {
case 'trackback':
/* translators: 1: Post title */
$notify_message = sprintf( __( 'New trackback on your post "%s"' ), $post->post_title ) . "\r\n";
- /* translators: 1: Trackback/pingback website name, 2: website IP, 3: website hostname */
- $notify_message .= sprintf( __('Website: %1$s (IP: %2$s, %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: Trackback/pingback website name, 2: website IP address, 3: website hostname */
+ $notify_message .= sprintf( __('Website: %1$s (IP address: %2$s, %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
$notify_message .= sprintf( __( 'URL: %s' ), $comment->comment_author_url ) . "\r\n";
$notify_message .= sprintf( __( 'Comment: %s' ), "\r\n" . $comment_content ) . "\r\n\r\n";
$notify_message .= __( 'You can see all trackbacks on this post here:' ) . "\r\n";
@@ -1480,8 +1480,8 @@ function wp_notify_postauthor( $comment_id, $deprecated = null ) {
case 'pingback':
/* translators: 1: Post title */
$notify_message = sprintf( __( 'New pingback on your post "%s"' ), $post->post_title ) . "\r\n";
- /* translators: 1: Trackback/pingback website name, 2: website IP, 3: website hostname */
- $notify_message .= sprintf( __('Website: %1$s (IP: %2$s, %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: Trackback/pingback website name, 2: website IP address, 3: website hostname */
+ $notify_message .= sprintf( __('Website: %1$s (IP address: %2$s, %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
$notify_message .= sprintf( __( 'URL: %s' ), $comment->comment_author_url ) . "\r\n";
$notify_message .= sprintf( __( 'Comment: %s' ), "\r\n" . $comment_content ) . "\r\n\r\n";
$notify_message .= __( 'You can see all pingbacks on this post here:' ) . "\r\n";
@@ -1490,8 +1490,8 @@ function wp_notify_postauthor( $comment_id, $deprecated = null ) {
break;
default: // Comments
$notify_message = sprintf( __( 'New comment on your post "%s"' ), $post->post_title ) . "\r\n";
- /* translators: 1: comment author, 2: author IP, 3: author domain */
- $notify_message .= sprintf( __( 'Author: %1$s (IP: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: comment author, 2: comment author's IP address, 3: comment author's hostname */
+ $notify_message .= sprintf( __( 'Author: %1$s (IP address: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
$notify_message .= sprintf( __( 'Email: %s' ), $comment->comment_author_email ) . "\r\n";
$notify_message .= sprintf( __( 'URL: %s' ), $comment->comment_author_url ) . "\r\n";
$notify_message .= sprintf( __('Comment: %s' ), "\r\n" . $comment_content ) . "\r\n\r\n";
@@ -1630,8 +1630,8 @@ function wp_notify_moderator($comment_id) {
/* translators: 1: Post title */
$notify_message = sprintf( __('A new trackback on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
- /* translators: 1: Trackback/pingback website name, 2: website IP, 3: website hostname */
- $notify_message .= sprintf( __( 'Website: %1$s (IP: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: Trackback/pingback website name, 2: website IP address, 3: website hostname */
+ $notify_message .= sprintf( __( 'Website: %1$s (IP address: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
/* translators: 1: Trackback/pingback/comment author URL */
$notify_message .= sprintf( __( 'URL: %s' ), $comment->comment_author_url ) . "\r\n";
$notify_message .= __('Trackback excerpt: ') . "\r\n" . $comment_content . "\r\n\r\n";
@@ -1640,8 +1640,8 @@ function wp_notify_moderator($comment_id) {
/* translators: 1: Post title */
$notify_message = sprintf( __('A new pingback on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
- /* translators: 1: Trackback/pingback website name, 2: website IP, 3: website hostname */
- $notify_message .= sprintf( __( 'Website: %1$s (IP: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: Trackback/pingback website name, 2: website IP address, 3: website hostname */
+ $notify_message .= sprintf( __( 'Website: %1$s (IP address: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
/* translators: 1: Trackback/pingback/comment author URL */
$notify_message .= sprintf( __( 'URL: %s' ), $comment->comment_author_url ) . "\r\n";
$notify_message .= __('Pingback excerpt: ') . "\r\n" . $comment_content . "\r\n\r\n";
@@ -1650,8 +1650,8 @@ function wp_notify_moderator($comment_id) {
/* translators: 1: Post title */
$notify_message = sprintf( __('A new comment on the post "%s" is waiting for your approval'), $post->post_title ) . "\r\n";
$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
- /* translators: 1: Comment author name, 2: comment author's IP, 3: comment author IP's hostname */
- $notify_message .= sprintf( __( 'Author: %1$s (IP: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
+ /* translators: 1: Comment author name, 2: comment author's IP address, 3: comment author's hostname */
+ $notify_message .= sprintf( __( 'Author: %1$s (IP address: %2$s, %3$s)' ), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
/* translators: 1: Comment author URL */
$notify_message .= sprintf( __( 'Email: %s' ), $comment->comment_author_email ) . "\r\n";
/* translators: 1: Trackback/pingback/comment author URL */